@@ -584,8 +584,7 @@ class MyMontezuma:
 class Montezuma(AtariEnvironment):
     def __init__(
         self,
-        dt: int = 1,
-        min_dt: int = 1,
+        frameskip: int = 1,
         episodic_live: bool = False,
         autoreset: bool = True,
         name=None,
@@ -595,12 +594,11 @@ class Montezuma(AtariEnvironment):
 
         super(Montezuma, self).__init__(
             name="MontezumaRevengeDeterministic-v4",
-            dt=dt,
             clone_seeds=True,
-            min_dt=min_dt,
+            frameskip=frameskip,
             obs_ram=False,
         )
-        self.gym_env = MyMontezuma(*args, **kwargs)
+        self._gym_env = MyMontezuma(*args, **kwargs)
         self.action_space = self.gym_env.action_space
         self.observation_space = self.gym_env.observation_space
         self.reward_range = self.gym_env.reward_range
@@ -609,6 +607,10 @@ class Montezuma(AtariEnvironment):
     def __getattr__(self, item):
         return getattr(self.gym_env, item)
 
+    @property
+    def obs_shape(self) -> typing.Tuple[int, ...]:
+        return (100803,)
+
     @property
     def n_actions(self):
         return self.gym_env.action_space.n
@@ -683,11 +685,11 @@ class Montezuma(AtariEnvironment):
         )
         self.gym_env.restore(data)
 
-    def step(self, action: np.ndarray, state: np.ndarray = None, dt: int = None) -> tuple:
+    def step(self, action: np.ndarray, state: np.ndarray = None, dt: int = 1) -> tuple:
         """
 
         Take dt simulation steps and make the environment evolve
-        in multiples of min_dt.
+        in multiples of frameskip.
         The info dictionary will contain a boolean called 'lost_live' that will
         be true if a life was lost during the current step.
 
@@ -700,7 +702,6 @@ class Montezuma(AtariEnvironment):
             if states is None returns (observs, rewards, ends, infos)
             else returns(new_states, observs, rewards, ends, infos)
         """
-        dt = dt if dt is not None else self.dt
         if state is not None:
             self.set_state(state)
         reward = 0
@@ -709,7 +710,7 @@ class Montezuma(AtariEnvironment):
         terminal = False
         game_end = False
         for _ in range(int(dt)):
-            for _ in range(self.min_dt):
+            for _ in range(self.frameskip):
                 obs, _reward, _end, _info = self.gym_env.step(action)
                 _info["lives"] = _info.get("ale.lives", -1)
                 lost_live = info["lives"] > _info["lives"] or lost_live
