@@ -2,9 +2,10 @@ import atexit
 import multiprocessing
 import sys
 import traceback
-from typing import Callable
+from typing import Callable, Tuple, Union
 
 import numpy
+import numpy as np
 
 from plangym.core import BaseEnvironment
 from plangym.utils import split_similar_chunks
@@ -316,7 +317,7 @@ class BatchEnv:
         """
         return getattr(self._envs[0], name)
 
-    def _make_transitions(self, actions, states=None, dt: [numpy.ndarray, int] = None):
+    def _make_transitions(self, actions, states=None, dt: [numpy.ndarray, int] = 1):
         no_states = states is None or states[0] is None
         states = states if states is not None else [None] * len(actions)
         if dt is None:
@@ -369,7 +370,7 @@ class BatchEnv:
             transitions = _states, observs, rewards, terminals, infos
         return transitions
 
-    def step_batch(self, actions, states=None, dt: [numpy.ndarray, int] = None):
+    def step_batch(self, actions, states=None, dt: [numpy.ndarray, int] = 1):
         """
         Forward a batch of actions to the wrapped environments.
 
@@ -469,7 +470,8 @@ class ParallelEnvironment(BaseEnvironment):
 
         >>> env = ParallelEnvironment(env_class=AtariEnvironment,
         >>>                           name="MsPacman-v0",
-        >>>                           clone_seeds=True, autoreset=True,
+        >>>                           clone_seeds=True,
+        >>>                           autoreset=True,
         >>>                           blocking=False)
         >>>
         >>> state, obs = env.reset()
@@ -485,19 +487,25 @@ class ParallelEnvironment(BaseEnvironment):
 
     def __init__(
         self,
-        name,
+        name: str,
+        frameskip: int = 1,
+        autoreset: bool = True,
+        delay_init: bool = False,
         env_class=None,
-        env_callable: Callable[..., BaseEnvironment] = None,
         n_workers: int = 8,
         blocking: bool = False,
-        *args,
         **kwargs,
     ):
         """
         Initialize a :class:`ParallelEnvironment`.
 
         Args:
-            name:  Name of the Environment.
+            name: Name of the environment.
+            frameskip: Number of times ``step`` will me called with the same action.
+            autoreset: Ignored. Always set to True. Automatically reset the environment
+                      when the OpenAI environment returns ``end = True``.
+            delay_init: If ``True`` do not initialize the ``gym.Environment`` \
+                     and wait for ``init_env`` to be called later.
             env_class: Class of the environment to be wrapped.
             env_callable: Callable that returns an instance of the environment \
                          that will be parallelized.
@@ -507,35 +515,74 @@ class ParallelEnvironment(BaseEnvironment):
             **kwargs: Additional kwargs for the environment.
 
         """
-        # Noqa: D202
-        def _env_callable(name, env_class, *args, **kwargs):
-            def _dummy():
-                return env_class(name, *args, **kwargs)
+        kwargs["autoreset"] = True
+        self._env_class = env_class
+        self._n_workers = n_workers
+        self._blocking = blocking
+        self._env_kwargs = kwargs
+        super(ParallelEnvironment, self).__init__(
+            name=name,
+            frameskip=frameskip,
+            autoreset=True,
+            delay_init=delay_init,
+        )
 
-            return _dummy
+    @property
+    def obs_shape(self) -> Tuple[int]:
+        """Tuple containing the shape of the observations returned by the Environment."""
+        return self.plangym_env.obs_shape
 
-        if env_class is None and env_callable is None:
-            raise ValueError("env_callable and env_class cannot be both None.")
-        env_callable = _env_callable if env_callable is None else env_callable
+    @property
+    def action_shape(self) -> Tuple[int]:
+        """Tuple containing the shape of the actions applied to the Environment."""
+        return self.plangym_env.action_shape
 
-        super(ParallelEnvironment, self).__init__(name=name)
-        self.plangym_env = env_callable(name, env_class, *args, **kwargs)()
-        envs = [
-            ExternalProcess(constructor=env_callable(name, env_class, *args, **kwargs))
-            for _ in range(n_workers)
-        ]
-        self._batch_env = BatchEnv(envs, blocking)
-        self.action_space = self.plangym_env.action_space
-        self.observation_space = self.plangym_env.observation_space
+    @property
+    def n_workers(self) -> int:
+        return self._n_workers
+
+    @property
+    def blocking(self) -> bool:
+        return self._blocking
 
     def __getattr__(self, item):
         return getattr(self.plangym_env, item)
 
+    @classmethod
+    def __from_callable(
+        cls,
+        env_callable: Callable[..., BaseEnvironment],
+        n_workers,
+        blocking,
+    ) -> "ParallelEnvironment":
+        return env_callable()
+
+    def init_env(self):
+        """Run environment initialization and create the subprocesses for stepping in parallel."""
+
+        def create_env_callable(env_class, **kwargs):
+            def _inner():
+                return env_class(**kwargs)
+
+            return _inner
+
+        env_callable = create_env_callable(
+            name=self.name,
+            env_class=self._env_class,
+            frameskip=self.frameskip,
+            delay_init=False,
+            **self._env_kwargs,
+        )
+
+        self.plangym_env = env_callable()
+        envs = [ExternalProcess(constructor=env_callable) for _ in range(self.n_workers)]
+        self._batch_env = BatchEnv(envs, blocking=self._blocking)
+
     def step_batch(
         self,
         actions: numpy.ndarray,
         states: numpy.ndarray = None,
-        dt: [numpy.ndarray, int] = None,
+        dt: [numpy.ndarray, int] = 1,
     ):
         """
         Vectorized version of the ``step`` method.
@@ -556,7 +603,7 @@ class ParallelEnvironment(BaseEnvironment):
         """
         return self._batch_env.step_batch(actions=actions, states=states, dt=dt)
 
-    def step(self, action: numpy.ndarray, state: numpy.ndarray = None, dt: int = None):
+    def step(self, action: numpy.ndarray, state: numpy.ndarray = None, dt: int = 1):
         """
         Step the environment applying a given action from an arbitrary state.
 
@@ -592,7 +639,7 @@ class ParallelEnvironment(BaseEnvironment):
         """
         state, obs = self.plangym_env.reset(return_state=True)
         self.sync_states(state)
-        return state, obs if return_state else obs
+        return (state, obs) if return_state else obs
 
     def get_state(self):
         """
@@ -625,3 +672,40 @@ class ParallelEnvironment(BaseEnvironment):
         """
         state = self.get_state() if state is None else state
         self._batch_env.sync_states(state)
+
+    def render(self, mode="human"):
+        """Render the environment using OpenGL. This wraps the OpenAI render method."""
+        return self.plangym_env.render(mode)
+
+    def get_image(self) -> np.ndarray:
+        """
+        Return a numpy array containing the rendered view of the environment.
+
+        Square matrices are interpreted as a greyscale image. Three-dimensional arrays
+         are interpreted as RGB images with channels (Height, Width, RGB)
+        """
+        return self.plangym_env.get_image()
+
+    def clone(self) -> "BaseEnvironment":
+        env = ParallelEnvironment(
+            name=self.name,
+            frameskip=self.frameskip,
+            delay_init=self.delay_init,
+            env_class=self._env_class,
+            n_workers=self.n_workers,
+            blocking=self.blocking,
+            **self._env_kwargs,
+        )
+        return env
+
+    def step_with_dt(self, action: Union[numpy.ndarray, int, float], dt: int = 1) -> tuple:
+        return self.plangym_env.step_with_dt(action=action, dt=dt)
+
+    def sample_action(self):
+        """
+        Return a valid action that can be used to step the Environment.
+
+        Implementing this method is optional, and it's only intended to make the
+         testing process of the Environment easier.
+        """
+        return self.plangym_env.sample_action()
