@@ -1,16 +1,14 @@
-import sys
-
 import pytest
 
 from plangym.classic_control import ClassicControl
-from tests.test_core import TestGymEnvironment
+from tests.api_tests import batch_size, TestGymEnvironment
 
 
 environments = [
     "MountainCar-v0",
     "Acrobot-v1",
     "MountainCarContinuous-v0",
-    f"Pendulum-v0",
+    "Pendulum-v0",
     "CartPole-v0",
 ]
 
