@@ -1,7 +1,7 @@
 import pytest
 
 from plangym.montezuma import Montezuma
-from tests.test_core import TestGymEnvironment
+from tests.api_tests import batch_size, TestGymEnvironment
 
 
 @pytest.fixture(scope="class")
